@@ -21,8 +21,9 @@ use strict;
 use base qw/Net::DRI::DRD/;
 
 use Net::DRI::DRD::ICANN;
+use DateTime::Duration;
 
-our $VERSION=do { my @r=(q$Revision: 1.3 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -99,7 +100,7 @@ sub transport_protocol_default
 {
  my ($drd,$ndr,$type,$ta,$pa)=@_;
  $type='epp' if (!defined($type) || ref($type));
- return Net::DRI::DRD::_transport_protocol_default_epp('Net::DRI::Protocol::EPP::Extensions::PIR',$ta,$pa) if ($type eq 'epp');
+ return Net::DRI::DRD::_transport_protocol_default_epp('Net::DRI::Protocol::EPP::Extensions::Afilias',$ta,$pa) if ($type eq 'epp');
  return ('Net::DRI::Transport::Socket',[{%Net::DRI::DRD::PROTOCOL_DEFAULT_WHOIS,remote_host=>'whois.publicinterestregistry.net'}],'Net::DRI::Protocol::Whois',[]) if (lc($type) eq 'whois');
 }
 
