@@ -20,9 +20,10 @@ package Net::DRI::DRD::PL;
 use strict;
 use base qw/Net::DRI::DRD/;
 
-use Net::DRI::Util;
+use Net::DRI::Exception;
+use DateTime::Duration;
 
-our $VERSION=do { my @r=(q$Revision: 1.3 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
