@@ -1,6 +1,6 @@
 ## Domain Registry Interface, AFNIC WS Message
 ##
-## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -24,7 +24,7 @@ use Net::DRI::Protocol::ResultStatus;
 use base qw(Class::Accessor::Chained::Fast Net::DRI::Protocol::Message);
 __PACKAGE__->mk_accessors(qw(version service method params result errcode));
 
-our $VERSION=do { my @r=(q$Revision: 1.5 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.6 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -54,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -66,6 +66,8 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
+####################################################################################################
+
 sub new
 {
  my $proto=shift;
@@ -135,16 +137,5 @@ sub result_status
  ## to find the correct key of the hash (and special case of free <=> 2303)
 }
 
-####################################################################################################
-
-sub get_name_from_message
-{
- my ($self)=@_;
- my $c=$self->method();
- my $rp=$self->params();
-
- return $rp->[0] if ($c eq 'check_domain');
-}
-
 ####################################################################################################
 1;
