@@ -22,7 +22,7 @@ use strict;
 use Net::DRI::Exception;
 use Net::DRI::Util;
 
-our $VERSION=do { my @r=(q$Revision: 1.8 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.9 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -101,48 +101,45 @@ sub parse_poll
  return unless $mes->is_success();
 
  my $msgid=$mes->msg_id();
- my $rd={};
- if (defined($msgid) && $msgid)
- {
-  $rinfo->{message}->{session}->{last_id}=$msgid;
-  $rd=$rinfo->{message}->{$msgid}; ## already partially filled by Message::parse()
- }
+ return unless (defined($msgid) && $msgid);
+ $rinfo->{message}->{session}->{last_id}=$msgid; ## needed here and not lower below, in case of pure text registry message
 
- if ($mes->result_code() == 1301 && (defined($mes->node_resdata()) || defined($mes->node_extension()) || defined($mes->node_msg()))) ## there was really a message with some content
+ ## Was there really a registry message with some content ?
+ return unless ($mes->result_code() == 1301 && (defined($mes->node_resdata()) || defined($mes->node_extension()) || defined($mes->node_msg())));
+
+ my $rd=$rinfo->{message}->{$msgid}; ## already partially filled by Message::parse()
+ my ($totype,$toaction,$toname); ## $toaction will remain undef, but could be $haction if only one
+ my %info;
+ my $h=$po->commands();
+
+ while (my ($htype,$hv)=each(%$h))
  {
-  my ($totype,$toaction,$toname); ## $toaction will remain undef, but could be $haction if only one
-  my %info;
-  my $h=$po->commands();
- 
-  while (my ($htype,$hv)=each(%$h))
+  while (my ($haction,$hv2)=each(%$hv))
   {
-   while (my ($haction,$hv2)=each(%$hv))
+   next if (($htype eq 'message') && ($haction eq 'retrieve')); ## calling myself here would be a very bad idea !
+   foreach my $t (@$hv2)
    {
-    next if (($htype eq 'message') && ($haction eq 'retrieve')); ## calling myself here would be a very bad idea !
-    foreach my $t (@$hv2)
-    {
-     my $pf=$t->[1];
-     next unless (defined($pf) && (ref($pf) eq 'CODE'));
-     $pf->($po,$totype,$toaction,$toname,\%info);
-     next unless keys(%info);
-     next if defined($toname);
-     Net::DRI::Exception::err_assert('EPP::parse_poll can not handle multiple types !') unless (keys(%info)==1);
-     $totype=(keys(%info))[0];
-     Net::DRI::Exception::err_assert('EPP::parse_poll can not handle multiple names !') unless (keys(%{$info{$totype}})==1); ## this may happen for check_multi !
-     $toname=(keys(%{$info{$totype}}))[0];
-     $info{$totype}->{$toname}->{name}=$toname;
-    }
+    my $pf=$t->[1];
+    next unless (defined($pf) && (ref($pf) eq 'CODE'));
+    $pf->($po,$totype,$toaction,$toname,\%info);
+    next unless keys(%info);
+    next if defined($toname);
+    Net::DRI::Exception::err_assert('EPP::parse_poll can not handle multiple types !') unless (keys(%info)==1);
+    $totype=(keys(%info))[0];
+    Net::DRI::Exception::err_assert('EPP::parse_poll can not handle multiple names !') unless (keys(%{$info{$totype}})==1); ## this may happen for check_multi !
+    $toname=(keys(%{$info{$totype}}))[0];
+    $info{$totype}->{$toname}->{name}=$toname;
    }
   }
-  Net::DRI::Exception::err_assert('EPP::parse_poll was not able to parse anything, please report !') unless $toname;
+ }
+ Net::DRI::Exception::err_assert('EPP::parse_poll was not able to parse anything, please report !') unless $toname;
 
-  ## Copy %info into $rd someway
-  $rd->{object_type}=$totype;
-  $rd->{object_id}=$toname; ## this has to be taken broadly, it is in fact a name for domains and hosts
-  while(my ($k,$v)=each(%{$info{$totype}->{$toname}}))
-  {
-   $rd->{$k}=$v;
-  }
+ ## Copy local %info into $rd (which is in fact global info as set above) someway (we're working with references)
+ $rd->{object_type}=$totype;
+ $rd->{object_id}=$toname; ## this has to be taken broadly, it is in fact a name for domains and hosts
+ while(my ($k,$v)=each(%{$info{$totype}->{$toname}}))
+ {
+  $rd->{$k}=$v;
  }
 
  ## TODO : optionnally, offer to merge this new information with already existing cache information
