@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP Status
 ##
-## Copyright (c) 2005,2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2007,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -23,7 +23,7 @@ use strict;
 
 use Net::DRI::Exception;
 
-our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.5 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -53,7 +53,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2007 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2007,2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -97,6 +97,11 @@ sub new
  return $self;
 }
 
+sub is_core_status
+{
+ return (shift=~m/^client(?:Hold|(?:Delete|Renew|Update|Transfer)Prohibited)$/);
+}
+
 sub build_xml
 {
  my ($self,$name,$range)=@_;
@@ -105,7 +110,7 @@ sub build_xml
  my $rd=$self->status_details();
  while(my ($k,$v)=each(%$rd))
  {
-  next if (($range eq 'core') xor ($k=~m/^client(?:Hold|(?:Delete|Renew|Update|Transfer)Prohibited)$/));
+  next if (($range eq 'core') xor is_core_status($k));
   if ($v && ref($v) && keys(%$v))
   {
    my %tmp=(s => $k);
