@@ -1,7 +1,6 @@
 ## Domain Registry Interface, .AU EPP extensions
 ##
-## Copyright (c) 2007-2009,2013 Distribute.IT Pty Ltd, www.distributeit.com.au, Rony Meyer <perl@spot-light.ch>. All rights reserved.
-## Copyright (c) 2018 Patrick Mevzek <netdri@dotandco.com>.
+## Copyright (c) 2007 Distribute.IT Pty Ltd, www.distributeit.com.au, Rony Meyer <perl@spot-light.ch>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,15 +10,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::AU;
 
 use strict;
-use warnings;
 
 use base qw/Net::DRI::Protocol::EPP/;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -48,8 +51,7 @@ Rony Meyer, E<lt>perl@spot-light.chE<gt>
  
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2009,2013 Distribute.IT Pty Ltd, E<lt>http://www.distributeit.com.auE<gt>, Rony Meyer <perl@spot-light.ch>.
-Copyright (c) 2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007 Distribute.IT Pty Ltd, E<lt>http://www.distributeit.com.auE<gt>, Rony Meyer <perl@spot-light.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -62,18 +64,24 @@ See the LICENSE file that comes with this distribution for more details.
 =cut
 
 ####################################################################################################
-
-sub setup
+sub new
 {
- my ($self,$rp)=@_;
- $self->ns({auext   => 'urn:au:params:xml:ns:auext-1.0',
-            auextnew=> 'urn:X-au:params:xml:ns:auext-1.1',
-          });
- $self->capabilities('domain_update','maintainer_url',['set']);
- return;
-}
+ my $h=shift;
+ my $c=ref($h) || $h;
 
-sub default_extensions { return qw/AU::Domain/; }
+ my ($drd,$version,$extrah)=@_;
+ my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
+
+ $e{'Net::DRI::Protocol::EPP::Extensions::AU::Domain'}=1;
+
+ my $self=$c->SUPER::new($drd,$version,[keys(%e)]); ## we are now officially a Net::DRI::Protocol::EPP object
+
+ $self->{ns}->{auext}=['urn:au:params:xml:ns:auext-1.0','auext-1.0.xsd'];
+ $self->{ns}->{auextnew}=['urn:X-au:params:xml:ns:auext-1.1','auext-1.1.xsd'];
+
+ bless($self,$c); ## rebless
+ return $self;
+}
 
 ####################################################################################################
 1;
