@@ -1,7 +1,6 @@
 ## Domain Registry Interface, Afilias EPP extensions
 ##
-## Copyright (c) 2007,2008,2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
-##           (c) 2010,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007,2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,15 +10,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::Afilias;
 
 use strict;
-use warnings;
 
 use base qw/Net::DRI::Protocol::EPP/;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -40,7 +43,8 @@ Please also see the SUPPORT file in the distribution.
 
 =head1 SEE ALSO
 
-E<lt>http://www.dotandco.com/services/software/Net-DRI/E<gt>
+E<lt>http://www.dotandco.com/services/software/Net-DRI/E<gt> and
+E<lt>http://oss.bsdprojects.net/projects/netdri/E<gt>
 
 =head1 AUTHOR
 
@@ -48,8 +52,7 @@ Tonnerre Lombard E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-          (c) 2010,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+Copyright (c) 2007,2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -63,14 +66,27 @@ See the LICENSE file that comes with this distribution for more details.
 
 ####################################################################################################
 
-sub setup
+sub new
 {
- my ($self,$rp)=@_;
- $self->ns({ oxrs => 'urn:afilias:params:xml:ns:oxrs-1.1' });
- return;
-}
+ my $c=shift;
+ my ($drd,$version,$extrah,$defproduct)=@_;
+ my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
 
-sub default_extensions { return qw/Afilias::Message Afilias::IDNLanguage Afilias::Restore GracePeriod SecDNS/; }
+ ## We do no load automatically IDNLanguage as we do not know if it is
+ ## mandatory
+ if (exists($e{':full'})) ## useful shortcut, modeled after Perl itself
+ {
+  delete($e{':full'});
+  $e{'Net::DRI::Protocol::EPP::Extensions::Afilias::IDNLanguage'}=1;
+  $e{'Net::DRI::Protocol::EPP::Extensions::Afilias::Restore'}=1;
+  $e{'Net::DRI::Protocol::EPP::Extensions::GracePeriod'}=1;
+ }
+
+ my $self=$c->SUPER::new($drd,$version,[keys(%e)]); ## we are now officially a Net::DRI::Protocol::EPP object
+
+ bless($self,$c); ## rebless
+ return $self;
+}
 
 ####################################################################################################
 1;
