@@ -1,7 +1,6 @@
 ## Domain Registry Interface, EPP IDN Language (EPP-IDN-Lang-Mapping.pdf)
 ##
-## Copyright (c) 2007,2008,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
-## Copyright (c) 2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,17 +10,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::Afilias::IDNLanguage;
 
 use strict;
-use warnings;
-use feature 'state';
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -51,8 +53,7 @@ Tonnerre Lombard E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-Copyright (c) 2016 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -69,9 +70,12 @@ See the LICENSE file that comes with this distribution for more details.
 sub register_commands
 {
  my ($class,$version)=@_;
- state $cmds = { 'domain' => { 'create' => [ \&create, undef ], 'check' => [ \&check, undef ] } };
+ my %tmp=(
+           create => [ \&create, undef ],
+           check =>  [ \&check, undef ],
+         );
 
- return $cmds;
+ return { 'domain' => \%tmp };
 }
 
 ####################################################################################################
@@ -81,25 +85,23 @@ sub add_language
  my ($tag,$epp,$domain,$rd)=@_;
  my $mes=$epp->message();
 
- if (Net::DRI::Util::has_key($rd,'language'))
+ if (defined($rd) && (ref($rd) eq 'HASH') && exists($rd->{language}))
  {
   Net::DRI::Exception::usererr_invalid_parameters('IDN language tag must be of type XML schema language') unless Net::DRI::Util::xml_is_language($rd->{language});
-  my $eid=$mes->command_extension_register('idn', $tag);
+
+  my $eid=$mes->command_extension_register($tag,'xmlns:idn="urn:iana:xml:ns:idn" xsi:schemaLocation="urn:iana:xml:ns:idn idn.xsd"');
   $mes->command_extension($eid,['idn:script', $rd->{language}]);
  }
- return;
 }
 
 sub create
 {
- my (@args)=@_;
- return add_language('create',@args);
+ return add_language('idn:create',@_);
 }
 
 sub check
 {
- my (@args)=@_;
- return add_language('check',@args);
+ return add_language('idn:check',@_);
 }
 
 ####################################################################################################
