@@ -1,7 +1,6 @@
 ## Domain Registry Interface, .CZ EPP extensions
 ##
-## Copyright (c) 2008,2009,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-## Copyright (c) 2018 Patrick Mevzek <netdri@dotandco.com>.
+## Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -12,15 +11,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::CZ;
 
 use strict;
-use warnings;
 
 use base qw/Net::DRI::Protocol::EPP/;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -50,8 +53,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-Copyright (c) 2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -65,24 +67,36 @@ See the LICENSE file that comes with this distribution for more details.
 
 ####################################################################################################
 
-sub setup
+sub new
 {
- my ($self,$rp)=@_;
+ my $c = shift;
+ my ($drd, $version, $extrah) = @_;
+ my %e = map { $_ => 1 } (defined($extrah) ? (ref($extrah) ? @$extrah :
+	($extrah)) : ());
+
+ $e{'Net::DRI::Protocol::EPP::Extensions::CZ::NSSET'} = 1;
+ $e{'Net::DRI::Protocol::EPP::Extensions::CZ::Contact'} = 1;
+ $e{'Net::DRI::Protocol::EPP::Extensions::CZ::Domain'} = 1;
+ $e{'Net::DRI::Protocol::EPP::Extensions::NSgroup'} = 1;
+
+ ## we are now officially a Net::DRI::Protocol::EPP object
+ my $self = $c->SUPER::new($drd,$version,[keys(%e)]);
+
  $self->{defaulti18ntype}='loc'; # The registry does not provide contact postalinfo i18n type, although it is mandatory by EPP
- $self->ns({ domain  => 'http://www.nic.cz/xml/epp/domain-1.4',
-             contact => 'http://www.nic.cz/xml/epp/contact-1.5',
-          });
- $self->capabilities('domain_update','status',undef);
- $self->capabilities('domain_update','nsset',['set']);
- $self->capabilities('nsset_update','ns',['add','del']);
- $self->capabilities('nsset_update','contact',['add','del']);
- $self->capabilities('nsset_update','auth',['set']);
- $self->capabilities('nsset_update','reportlevel',['set']);
- return;
+ $self->{ns}->{domain} = ['http://www.nic.cz/xml/epp/domain-1.3',
+	'domain-1.3.xsd'];
+ $self->{ns}->{contact} = ['http://www.nic.cz/xml/epp/contact-1.4',
+	'contact-1.4.xsd'];
+
+ my $rcapa = $self->capabilities();
+ delete($rcapa->{domain_update}->{status});
+ $rcapa->{domain_update}->{nsset} = ['set'];
+
+ bless($self, $c); ## rebless
+ return $self;
 }
 
 sub core_contact_types { return ('admin','tech','billing','onsite'); }
-sub default_extensions { return qw/CZ::NSSET CZ::Contact CZ::Domain NSgroup/; }
 
 ####################################################################################################
 1;
