@@ -1,7 +1,6 @@
 ## Domain Registry Interface, .CZ Contact EPP extension commands
 ##
-## Copyright (c) 2008,2010,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-##               2018 Patrick Mevzek <netdri@dotandco.com>.
+## Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -12,16 +11,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+#  
+#
 #########################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::CZ::Contact;
 
 use strict;
-use warnings;
 
 use Net::DRI::Exception;
 use Net::DRI::Util;
-use Net::DRI::Protocol::EPP::Util;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -52,8 +54,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2010,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-              2018 Patrick Mevzek <netdri@dotandco.com>
+Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -100,7 +101,10 @@ sub build_command
 	}
 
 	my $tcommand = (ref($command)) ? $command->[0] : $command;
-	$msg->command([$command, 'contact:' . $tcommand, $msg->nsattrs('contact')]);
+	my @ns = @{$msg->ns->{contact}};
+	$msg->command([$command, 'contact:' . $tcommand,
+		sprintf('xmlns:contact="%s" xsi:schemaLocation="%s %s"',
+		$ns[0], $ns[0], $ns[1])]);
 
 	my @d = map { ['contact:id', $_] } @c;
 	if (($tcommand =~ m/^(?:info|transfer)$/) && ref($contact[0]) &&
@@ -125,7 +129,7 @@ sub info_parse
 
 	return unless $mes->is_success();
 
-	my $infdata = $mes->get_response('contact','infData');
+	my $infdata = $mes->get_content('infData', $mes->ns('contact'), 0);
 	return unless $infdata;
 
 	my $s = $rinfo->{contact}->{$oname}->{self};
@@ -137,11 +141,23 @@ sub info_parse
 			if (defined($ai) && defined($ai->getFirstChild()) &&
 				$ai->getFirstChild()->nodeType() == 3);
 	}
-        return;
 }
 
 ############ Transform commands
 
+sub build_tel
+{
+	my ($name, $tel) = @_;
+	if ($tel=~m/^(\S+)x(\S+)$/)
+	{
+		return [$name, $1, { x => $2 }];
+	}
+	else
+	{
+		return [$name, $tel];
+	}
+}
+
 sub build_authinfo
 {
 	my $contact = shift;
@@ -201,9 +217,9 @@ sub build_cdata
 
 	push(@post, ['contact:addr', @addr]) if (@addr);
 	push(@d, ['contact:postalInfo', @post]);
-	push(@d, Net::DRI::Protocol::EPP::Util::build_tel('contact:voice', $contact->voice()))
+	push(@d, build_tel('contact:voice', $contact->voice()))
 		if (defined($contact->voice()));
-	push(@d, Net::DRI::Protocol::EPP::Util::build_tel('contact:fax', $contact->fax()))
+	push(@d, build_tel('contact:fax', $contact->fax()))
 		if (defined($contact->fax()));
 	push(@d, ['contact:email', $contact->email()])
 		if (defined($contact->email()));
@@ -224,7 +240,6 @@ sub create
 	$contact->validate(); ## will trigger an Exception if needed
 	push(@d, build_cdata($contact, $epp->{contacti18n}));
 	$mes->command_body(\@d);
-        return;
 }
 
 sub update 
@@ -264,7 +279,6 @@ sub update
 	}
 
 	$mes->command_body(\@d);
-        return;
 }
 
 ####################################################################################################
