@@ -1,7 +1,6 @@
 ## Domain Registry Interface, CZ domain transactions extension
 ##
-## Copyright (c) 2008-2010,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-##               2018 Patrick Mevzek <netdri@dotandco.com>
+## Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -12,21 +11,24 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::CZ::Domain;
 
 use strict;
-use warnings;
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
 use Net::DRI::Data::ContactSet;
 use Net::DRI::Data::Hosts;
-use Net::DRI::Protocol::EPP::Util;
 
 use DateTime::Format::ISO8601;
 
+our $VERSION = do { my @r = ( q$Revision: 1.1 $ =~ /\d+/g ); sprintf( "%d" . ".%02d" x $#r, @r ); };
+
 =pod
 
 =head1 NAME
@@ -55,8 +57,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2010,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-              2018 Patrick Mevzek <netdri@dotandco.com>
+Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -101,7 +102,11 @@ sub build_command
 	}
 
 	my $tcommand = (ref($command)) ? $command->[0] : $command;
-	$msg->command([$command, 'domain:' . $tcommand, $msg->nsattrs('domain')]);
+	my @ns = @{$msg->ns->{domain}};
+	$msg->command([$command, 'domain:' . $tcommand,
+		sprintf('xmlns:domain="%s" xsi:schemaLocation="%s %s"',
+			$ns[0], $ns[0], $ns[1])]);
+
 	my @d = map { ['domain:name', $_, $domainattr] } @dom;
 	return @d;
 }
@@ -112,7 +117,36 @@ sub build_authinfo
 	return ['domain:authInfo', $rauth->{pw}];
 }
 
-####################################################################################################
+sub build_period
+{
+	my $dtd = shift; ## DateTime::Duration
+	## all values are integral, but may be negative
+	my ($y, $m) = $dtd->in_units('years', 'months');
+	($y, $m) = (0, $m + 12 * $y) if ($y && $m);
+	my ($v, $u);
+
+	if ($y)
+	{
+		Net::DRI::Exception::usererr_invalid_parameters('years must ' .
+			'be between 1 and 99') unless ($y >= 1 && $y <= 99);
+		$v = $y;
+		$u = 'y';
+	}
+	else
+	{
+		Net::DRI::Exception::usererr_invalid_parameters('months must ' .
+			'be between 1 and 99') unless ($m >= 1 && $m <= 99);
+		$v = $m;
+		$u = 'm';
+	}
+ 
+	return ['domain:period', $v, {'unit' => $u}];
+}
+
+
+##################################################################################################
+
+
 ########### Query commands
 
 sub info
@@ -122,7 +156,6 @@ sub info
 	my @d = build_command($mes, 'info', $domain);
 	push(@d, build_authinfo($rd->{auth})) if Net::DRI::Util::has_auth($rd);
 	$mes->command_body(\@d);
-        return;
 }
 
 sub info_parse
@@ -130,10 +163,11 @@ sub info_parse
 	my ($po, $otype, $oaction, $oname, $rinfo) = @_;
 	my $mes = $po->message();
 	return unless $mes->is_success();
-	my $infdata = $mes->get_response('domain','infData');
+	my $infdata = $mes->get_content('infData', $mes->ns('domain'));
 	return unless $infdata;
 	my (@s, @host, $ns);
 	my $cs = Net::DRI::Data::ContactSet->new();
+	my $cf = $po->factories()->{contact};
 	my $c = $infdata->getFirstChild();
 
 	while ($c)
@@ -153,11 +187,11 @@ sub info_parse
 		}
 		elsif ($name eq 'status')
 		{
-			push(@s, Net::DRI::Protocol::EPP::Util::parse_node_status($c));
+			push(@s, Net::DRI::Protocol::EPP::parse_status($c));
 		}
 		elsif ($name =~ /^(registrant|admin)$/)
 		{
-			$cs->set($po->create_local_object('contact')->srid($c->getFirstChild()->getData()),
+			$cs->set($cf->()->srid($c->getFirstChild()->getData()),
 				$1);
 		}
 		elsif ($name eq 'ns')
@@ -202,7 +236,6 @@ sub info_parse
 	$rinfo->{domain}->{$oname}->{host} = Net::DRI::Data::Hosts->
 		new_set(@host) if (@host);
 	$rinfo->{domain}->{$oname}->{ns} = $ns if ($ns);
-        return;
 }
 
 ############ Transform commands
@@ -227,7 +260,7 @@ sub create
 	}
 
 	## Period, OPTIONAL
-	push(@d, Net::DRI::Protocol::EPP::Util::build_period($rd->{duration})) if Net::DRI::Util::has_duration($rd);
+	push(@d, build_period($rd->{duration})) if Net::DRI::Util::has_duration($rd);
 
 	## Nameserver sets, OPTIONAL
 	push(@d, ['domain:nsset', $rd->{nsset}]) if (Net::DRI::Util::has_key($rd, 'nsset'));
@@ -241,7 +274,6 @@ sub create
 		unless (Net::DRI::Util::has_auth($rd));
 	push(@d, build_authinfo($rd->{auth}));
 	$mes->command_body(\@d);
-        return;
 }
 
 sub build_contacts
@@ -287,11 +319,11 @@ sub update
 	my $cdel = $todo->del('contact');
 	my (@add, @del);
 
-	push(@add, Net::DRI::Protocol::EPP::Util::build_ns($epp, $nsadd, $domain))		if ($nsadd &&
+	push(@add, build_ns($epp, $nsadd, $domain))		if ($nsadd &&
 		!$nsadd->is_empty());
 	push(@add, build_contacts($cadd))			if ($cadd);
 	push(@add, $sadd->build_xml('domain:status', 'core'))	if ($sadd);
-	push(@del, Net::DRI::Protocol::EPP::Util::build_ns($epp, $nsdel, $domain))		if ($nsdel &&
+	push(@del, build_ns($epp, $nsdel, $domain))		if ($nsdel &&
 		!$nsdel->is_empty());
 	push(@del, build_contacts($cdel))			if ($cdel);
 	push(@del, $sdel->build_xml('domain:status', 'core'))	if ($sdel);
@@ -310,7 +342,6 @@ sub update
 	push(@d, ['domain:chg', @chg]) if (@chg);
 
 	$mes->command_body(\@d);
-        return;
 }
 
 ####################################################################################################
