@@ -1,7 +1,6 @@
 ## Domain Registry Interface, .CZ EPP NSSET extension commands
 ##
-## Copyright (c) 2008,2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-##           (c) 2010,2013,2018 Patrick Mevzek <netdri@dotandco.com>
+## Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -12,19 +11,23 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+#  
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::CZ::NSSET;
 
 use strict;
-use warnings;
-use feature 'state';
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
 use Net::DRI::Data::Hosts;
 use Net::DRI::Data::ContactSet;
-use Net::DRI::Protocol::EPP::Util;
+
+use DateTime::Format::ISO8601;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -54,8 +57,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-          (c) 2010,2013,2018 Patrick Mevzek <netdri@dotandco.com>
+Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -89,13 +91,21 @@ sub register_commands
 	return { 'nsset' => \%tmp1 };
 }
 
-sub setup
+sub capabilities_add
 {
- my ($class,$po,$version)=@_;
+	return { 'nsset_update' => {
+		'ns' =>			['add', 'del'],
+		'contact' =>		['add', 'del'],
+		'auth' =>		['set'],
+		'reportlevel' =>	['set']
+	} };
+}
 
- state $ns = { 'nsset' => 'http://www.nic.cz/xml/epp/nsset-1.2' };
- $po->ns($ns);
- return;
+sub ns
+{
+	my ($mes) = @_;
+	return (exists($mes->ns->{nsset})) ? $mes->ns->{nsset}->[0] :
+		'http://www.nic.cz/xml/epp/nsset-1.2';
 }
 
 sub build_command
@@ -120,7 +130,11 @@ sub build_command
 	Net::DRI::Exception->die(1, 'protocol/EPP', 2, 'NSgroup name needed')
 		unless @gn;
 
-	$msg->command([$command, 'nsset:' . $tcommand, $msg->nsattrs('nsset')]);
+	my @ns = exists($msg->ns->{nsset}) ? @{$msg->ns->{nsset}} :
+		('http://www.nic.cz/xml/epp/nsset-1.2', 'nsset-1.2.xsd');
+	$msg->command([$command, 'nsset:' . $tcommand,
+		sprintf('xmlns:nsset="%s" xsi:schemaLocation="%s %s"',
+			$ns[0], $ns[0], $ns[1])]);
 
 	return map { ['nsset:id', $_] } @gn;
 }
@@ -191,12 +205,12 @@ sub build_reportlevel
 
 sub check
 {
-	my ($epp, @hosts)=@_;
+	my $epp = shift;
+	my @hosts = @_;
 	my $mes = $epp->message();
 	my @d = build_command($epp, $mes, 'check', \@hosts);
 
 	$mes->command_body(\@d);
-	return;
 }
 
 sub check_parse
@@ -205,10 +219,11 @@ sub check_parse
 	my $mes = $po->message();
 	return unless $mes->is_success();
 
-	my $chkdata = $mes->get_response('nsset', 'chkData');
+	my $ns = ns($mes);
+	my $chkdata = $mes->get_content('chkData', $ns);
 	return unless $chkdata;
 
-	foreach my $cd ($chkdata->getElementsByTagNameNS($mes->ns('nsset'), 'cd'))
+	foreach my $cd ($chkdata->getElementsByTagNameNS($ns, 'cd'))
 	{
 		my $c = $cd->getFirstChild();
 		my $nsset;
@@ -228,7 +243,6 @@ sub check_parse
 			}
 		} continue { $c = $c->getNextSibling(); }
 	}
-	return;
 }
 
 sub info
@@ -238,7 +252,6 @@ sub info
 	my @d = build_command($epp, $mes, 'info', $hosts);
 
 	$mes->command_body(\@d);
-	return;
 }
 
 sub info_parse
@@ -247,10 +260,12 @@ sub info_parse
 	my $mes = $po->message();
 	return unless $mes->is_success();
 
-	my $infdata = $mes->get_response('nsset','infData');
+	my $infdata = $mes->get_content('infData', ns($mes));
 	return unless $infdata;
 
 	my $ns = Net::DRI::Data::Hosts->new();
+	my $pd = DateTime::Format::ISO8601->new();
+	my $cf = $po->factories()->{contact};
 	my $cs = Net::DRI::Data::ContactSet->new();
         my @s;
 	my $c = $infdata->getFirstChild();
@@ -279,7 +294,7 @@ sub info_parse
 		}
 		elsif ($name eq 'status')
 		{
-			push(@s,Net::DRI::Protocol::EPP::Util::parse_node_status($c));
+			push(@s, Net::DRI::Protocol::EPP::parse_status($c));
 		}
 		elsif ($name eq 'authInfo')
 		{
@@ -293,19 +308,20 @@ sub info_parse
 		}
 		elsif ($name =~ /^((?:c[lr]|tr|up)Date)$/)
 		{
-			$rinfo->{nsset}->{$oname}->{$1} = $po->parse_iso8601($c->textContent());
+			$rinfo->{nsset}->{$oname}->{$1} = $pd->parse_datetime(
+				$c->getFirstChild()->getData());
 		}
 		elsif ($name eq 'ns')
 		{
 			my $hostname;
 			my @v4;
 			my @v6;
-			foreach my $xname ($c->getElementsByTagNameNS($mes->ns('nsset'),
+			foreach my $xname ($c->getElementsByTagNameNS(ns($mes),
 				'name'))
 			{
 				$hostname = $xname->getFirstChild()->getData();
 			}
-			foreach my $xaddr ($c->getElementsByTagNameNS($mes->ns('nsset'),
+			foreach my $xaddr ($c->getElementsByTagNameNS(ns($mes),
 				'addr'))
 			{
 				my $xa = $xaddr->getFirstChild()->getData();
@@ -322,7 +338,7 @@ sub info_parse
 		}
 		elsif ($name =~ /^(registrant|billing|admin|tech)$/)
 		{
-			$cs->add($po->create_local_object('contact')->srid($c->getFirstChild()->getData()),
+			$cs->add($cf->()->srid($c->getFirstChild()->getData()),
 				$name);
 		}
 	} continue { $c = $c->getNextSibling(); }
@@ -330,7 +346,6 @@ sub info_parse
 	$rinfo->{nsset}->{$oname}->{self} = $ns;
 	$rinfo->{nsset}->{$oname}->{contact} = $cs;
 	$rinfo->{nsset}->{$oname}->{status} = $po->create_local_object('status')->add(@s);
-	return;
 }
 
 sub transfer_query
@@ -341,7 +356,6 @@ sub transfer_query
 		$name);
 	push(@d, build_authinfo($rd->{auth})) if Net::DRI::Util::has_auth($rd);
 	$mes->command_body(\@d);
-	return;
 }
 
 ############ Transform commands
@@ -359,17 +373,15 @@ sub create
 	push(@d, build_authinfo($rd->{auth}));
 	push(@d, build_reportlevel($rd->{reportlevel}));
 	$mes->command_body(\@d);
-	return;
 }
 
-sub delete ## no critic (Subroutines::ProhibitBuiltinHomonyms)
+sub delete
 {
 	my ($epp, $hosts) = @_;
 	my $mes = $epp->message();
 	my @d = build_command($epp, $mes, 'delete', $hosts);
 
 	$mes->command_body(\@d);
-	return;
 }
 
 sub transfer_request
@@ -381,7 +393,6 @@ sub transfer_request
 
 	push(@d, build_authinfo($rd->{auth})) if Net::DRI::Util::has_auth($rd);
 	$mes->command_body(\@d);
-	return;
 }
 
 sub transfer_answer
@@ -394,7 +405,6 @@ sub transfer_answer
 
 	push(@d, build_authinfo($rd->{auth})) if Net::DRI::Util::has_auth($rd);
 	$mes->command_body(\@d);
-	return;
 }
 
 sub transfer_cancel
@@ -406,7 +416,6 @@ sub transfer_cancel
 
 	push(@d, build_authinfo($rd->{auth})) if Net::DRI::Util::has_auth($rd);
 	$mes->command_body(\@d);
-	return;
 }
 
 sub update
@@ -451,7 +460,6 @@ sub update
 	push(@d, ['nsset:chg', @set]) if (@set);
 
 	$mes->command_body(\@d);
-	return;
 }
 
 ####################################################################################################
