@@ -1,8 +1,7 @@
 ## Domain Registry Interface, .NO Contact extensions
 ##
-## Copyright (c) 2008,2010 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
+## Copyright (c) 2008 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 ##                    Trond Haugen E<lt>info@norid.noE<gt>
-##           (c) 2016,2019 Patrick Mevzek E<lt>netdri@dotandco.comE<gt>
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -13,16 +12,18 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::NO::Contact;
 
 use strict;
-use warnings;
-
 use Net::DRI::Util;
-use Net::DRI::Protocol::EPP::Util;
-use Net::DRI::Protocol::EPP::Extensions::NO::Host;
+use Net::DRI::Protocol::EPP::Core::Contact;
+
+our $VERSION = do { my @r = ( q$Revision: 1.1 $ =~ /\d+/gmx ); sprintf( "%d" . ".%02d" x $#r, @r ); };
 
 =pod
 
@@ -52,9 +53,8 @@ Trond Haugen, E<lt>info@norid.noE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2010 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
+Copyright (c) 2008 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 Trond Haugen E<lt>info@norid.noE<gt>
-Copyright (c) 2016,2019 Patrick Mevzek E<lt>netdri@dotandco.comE<gt>
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -71,12 +71,9 @@ See the LICENSE file that comes with this distribution for more details.
 sub register_commands {
     my ( $class, $version ) = @_;
     my %tmp = (
-        check  => [ \&facet,  undef ],
-        info   => [ \&facet,  \&parse_info ],
-       delete => [ \&facet,  undef ],
         create => [ \&create, undef ],
+        info   => [ undef,    \&parse_info ],
         update => [ \&update, undef ],
-
     );
 
     return { 'contact' => \%tmp };
@@ -110,7 +107,8 @@ sub parse_info {
     my $mes = $po->message();
     return unless $mes->is_success();
 
-    my $NS = $mes->ns('no-ext-contact');
+    my @ns = @{ $mes->ns->{no_contact} };
+    my $NS = $ns[0];
 
     my $c = $rinfo->{contact}->{$oname}->{self};
 
@@ -121,7 +119,7 @@ sub parse_info {
         && $oaction    eq 'info'
         && $c->email() eq 'n/a' );
 
-    my $condata = $mes->get_extension('no-ext-contact','infData');
+    my $condata = $mes->get_content( 'infData', $NS, 1 );
     return unless $condata;
 
     # type
@@ -145,7 +143,7 @@ sub parse_info {
     @e = $condata->getElementsByTagNameNS( $NS, 'mobilePhone' );
     if ( @e && $e[0] ) {
         $c->mobilephone(
-            Net::DRI::Protocol::EPP::Util::parse_tel( $e[0] ) );
+            Net::DRI::Protocol::EPP::Core::Contact::parse_tel( $e[0] ) );
         $rinfo->{contact}->{$oname}->{identity} = $c->mobilephone();
     }
 
@@ -203,14 +201,23 @@ sub parse_info {
     return;
 }
 
-sub facet {
-    my ( $epp, $o, $rd ) = @_;
+sub build_command_extension {
+    my ( $mes, $epp, $tag ) = @_;
 
-    return Net::DRI::Protocol::EPP::Extensions::NO::Host::build_facets( $epp, $rd );
+    my @ns = @{ $mes->ns->{no_contact} };
+
+    return $mes->command_extension_register(
+        $tag,
+        sprintf(
+            'xmlns:no-ext-contact="%s" xsi:schemaLocation="%s %s"',
+            $ns[0], $ns[0], $ns[1]
+        )
+    );
 }
 
 sub add_no_extensions {
     my ( $epp, $contact, $op ) = @_;
+    my $mes = $epp->message();
 
     my $ty  = $contact->type();
     my $id  = $contact->identity();
@@ -219,7 +226,6 @@ sub add_no_extensions {
     my $rc  = $contact->rolecontact();
     my $aem = $contact->xemail();
     my $xd  = $contact->xdisclose();
-    my $fs  = $contact->facets();
 
     return
         unless ( defined($ty)
@@ -227,10 +233,9 @@ sub add_no_extensions {
         || defined($mp)
         || defined($org)
         || defined($rc)
-        || defined($aem)
-       || defined($fs)
-       );
+        || defined($aem) );
 
+    my $eid = build_command_extension( $mes, $epp, 'no-ext-contact:' . $op );
     my @e;
 
     push @e, [ 'no-ext-contact:type', $ty ] if ( defined($ty) && $ty );
@@ -250,7 +255,7 @@ sub add_no_extensions {
 
     #mobile is an e164 number
     push @e,
-        Net::DRI::Protocol::EPP::Util::build_tel(
+        Net::DRI::Protocol::EPP::Core::Contact::build_tel(
         'no-ext-contact:mobilePhone', $mp )
         if defined($mp);
 
@@ -307,16 +312,7 @@ sub add_no_extensions {
             [ 'no-ext-contact:disclose', @d, { flag => ( keys(%v) )[0] } ];
 	}
     }
-    my $r = $epp->message()->command_extension( 'no-ext-contact', [ $op, @e ] );
-
-    # Add facet if any is set
-    if ($fs) {
-       my $rd;
-       $rd->{facets} = $fs;
-       $r = facet($epp, $contact, $rd);
-    }
-
-    return $r;
+    return $mes->command_extension( $eid, \@e );
 }
 
 sub create {
@@ -326,12 +322,11 @@ sub create {
 
 sub update {
     my ( $epp, $co, $todo ) = @_;
+    my $mes = $epp->message();
 
-    my $r;
     my $mp = $todo->set('mobilephone');
     my $id = $todo->set('identity');
     my $xd = $todo->set('xdisclose');
-    my $fs = $todo->set('facets');
 
     my $orgtoadd = $todo->add('organization');
     my $orgtodel = $todo->del('organization');
@@ -342,18 +337,8 @@ sub update {
     my $xetoadd = $todo->add('xemail');
     my $xetodel = $todo->del('xemail');
 
-    return unless ( defined($mp)
-                   || $id
-                   || $orgtoadd
-                   || $orgtodel
-                   || $rctoadd
-                   || $rctodel
-                   || $xetoadd
-                   || $xetodel
-                   || $xd
-                   || $fs);
-
-    if ( defined($mp)
+    return
+        unless ( defined($mp)
         || $id
         || $orgtoadd
         || $orgtodel
@@ -361,85 +346,78 @@ sub update {
         || $rctodel
         || $xetoadd
         || $xetodel
-        || $xd) {
+        || $xd );
 
-       my ( @n, @s );
+    my $eid = build_command_extension( $mes, $epp, 'no-ext-contact:update' );
 
-       if ( defined($mp) ) {
-           push @s,
-            Net::DRI::Protocol::EPP::Util::build_tel(
-               'no-ext-contact:mobilePhone', $mp );
-       }
-       if (   defined($id)
-              && ( ref($id) eq 'HASH' )
-              && exists( $id->{type} )
-              && exists( $id->{value} ) )
-       {
-           push @s,
+    my ( @n, @s );
+
+    if ( defined($mp) ) {
+        push @s,
+            Net::DRI::Protocol::EPP::Core::Contact::build_tel(
+            'no-ext-contact:mobilePhone', $mp );
+    }
+    if (   defined($id)
+        && ( ref($id) eq 'HASH' )
+        && exists( $id->{type} )
+        && exists( $id->{value} ) )
+    {
+        push @s,
             [
             'no-ext-contact:identity', { type => $id->{type} },
             $id->{value}
             ];
-       }
+    }
 
-       # xdisclose
-       if ( ref($xd) && $xd ) {
-           my @d;
-           my %v = map { $_ => 1 } values(%$xd);
-           push @d, ['no-ext-contact:mobilePhone']
-               if exists( $xd->{mobilePhone} );
-           push @s,
+    # xdisclose
+    if ( ref($xd) && $xd ) {
+        my @d;
+        my %v = map { $_ => 1 } values(%$xd);
+        push @d, ['no-ext-contact:mobilePhone']
+            if exists( $xd->{mobilePhone} );
+        push @s,
             [ 'no-ext-contact:disclose', @d, { flag => ( keys(%v) )[0] } ];
-       }
-       push @n, [ 'no-ext-contact:chg', @s ] if ( @s > 0 );
+    }
+    push @n, [ 'no-ext-contact:chg', @s ] if ( @s > 0 );
 
-       @s = undef;
-       if (   ( defined($orgtoadd) || defined($rctoadd) || defined($xetoadd) )
-              && ( $rctoadd || $orgtoadd || $xetoadd ) )
-       {
-           push @s,
+    @s = undef;
+    if (   ( defined($orgtoadd) || defined($rctoadd) || defined($xetoadd) )
+        && ( $rctoadd || $orgtoadd || $xetoadd ) )
+    {
+        push @s,
             map { [ 'no-ext-contact:email', $_ ] }
             ( ref($xetoadd) eq 'ARRAY' ) ? @$xetoadd : ($xetoadd)
-               if ($xetoadd);
-           push @s,
+            if ($xetoadd);
+        push @s,
             map { [ 'no-ext-contact:organization', $_ ] }
             ( ref($orgtoadd) eq 'ARRAY' ) ? @$orgtoadd : ($orgtoadd)
-               if ($orgtoadd);
-           push @s,
+            if ($orgtoadd);
+        push @s,
             map { [ 'no-ext-contact:roleContact', $_ ] }
             ( ref($rctoadd) eq 'ARRAY' ) ? @$rctoadd : ($rctoadd)
-               if ($rctoadd);
-           push @n, [ 'no-ext-contact:add', @s ] if ( @s > 0 );
-       }
-       @s = undef;
-       if (   defined($orgtodel)
-              || defined( $rctodel || defined($xetoadd) )
-              && ( $rctodel || $orgtodel || $xetodel ) )
-       {
-           push @s,
+            if ($rctoadd);
+        push @n, [ 'no-ext-contact:add', @s ] if ( @s > 0 );
+    }
+    @s = undef;
+    if (   defined($orgtodel)
+        || defined( $rctodel || defined($xetoadd) )
+        && ( $rctodel || $orgtodel || $xetodel ) )
+    {
+        push @s,
             map { [ 'no-ext-contact:email', $_ ] }
             ( ref($xetodel) eq 'ARRAY' ) ? @$xetodel : ($xetodel)
-               if ($xetodel);
-           push @s,
+            if ($xetodel);
+        push @s,
             map { [ 'no-ext-contact:organization', $_ ] }
             ( ref($orgtodel) eq 'ARRAY' ) ? @$orgtodel : ($orgtodel)
-               if ($orgtodel);
-           push @s,
+            if ($orgtodel);
+        push @s,
             map { [ 'no-ext-contact:roleContact', $_ ] }
             ( ref($rctodel) eq 'ARRAY' ) ? @$rctodel : ($rctodel)
-               if ($rctodel);
-           push @n, [ 'no-ext-contact:rem', @s ] if ( @s > 0 );
-       }
-       $r = $epp->message()->command_extension( 'no-ext-contact', [ 'update', @n ] );
+            if ($rctodel);
+        push @n, [ 'no-ext-contact:rem', @s ] if ( @s > 0 );
     }
-
-    if ($fs) {
-       my $rd;
-       $rd->{facets} = $fs;
-       $r = facet($epp, $co, $rd);
-       
-    }
-    return $r;
+    return $mes->command_extension( $eid, \@n );
 }
 
 ####################################################################################################
