@@ -1,8 +1,7 @@
 ## Domain Registry Interface, .NO Result extension
 ##
-## Copyright (c) 2008,2010,2013,2019 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
+## Copyright (c) 2008 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 ##                    Trond Haugen E<lt>info@norid.noE<gt>
-## Copyright (c) 2016 Patrick Mevzek <netdri@dotandco.com>.
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -13,12 +12,16 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::NO::Result;
 
 use strict;
-use warnings;
+
+our $VERSION = do { my @r = ( q$Revision: 1.1 $ =~ /\d+/gxm ); sprintf( "%d" . ".%02d" x $#r, @r ); };
 
 =pod
 
@@ -48,9 +51,8 @@ Trond Haugen, E<lt>info@norid.noE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2010,2013,2019 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
+Copyright (c) 2008 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 Trond Haugen, E<lt>info@norid.noE<gt>
-Copyright (c) 2016 Patrick Mevzek <netdri@dotandco.com>
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -68,6 +70,9 @@ sub register_commands {
     my ( $class, $version ) = @_;
     my %tmp = (
 
+        # hmmm, would like to parse our login response extensions as well,
+        # but that doesn't work ..
+        #login            => [ undef, \&condition_parse ],
         check            => [ undef, \&condition_parse ],
         info             => [ undef, \&condition_parse ],
         create           => [ undef, \&condition_parse ],
@@ -85,8 +90,7 @@ sub register_commands {
     return {
         'domain'  => \%tmp,
         'contact' => \%tmp,
-        'host'    => \%tmp,
-	'session' => { 'login' => [ undef, \&condition_parse ] },
+        'host'    => \%tmp
     };
 }
 
@@ -94,19 +98,16 @@ sub condition_parse {
     my ( $po, $otype, $oaction, $oname, $rinfo ) = @_;
     my $mes = $po->message();
 
-    my $condata = $mes->get_extension( 'no-ext-result', 'conditions' );
+    my @ns = @{ $mes->ns->{no_result} };
+    my $NS = $ns[0];
+
+    my $condata = $mes->get_content( 'conditions', $NS, 1 );
+
     return unless $condata;
 
-    parse( $mes, $otype, $oname, $rinfo, $condata );
-    return 1;
-}
-
-sub parse {
-    my ( $mes, $otype, $oname, $rinfo, $node ) = @_;
-    my $NS = $mes->ns('no-ext-result');
     my @conditions;
 
-    foreach my $el ( $node->getElementsByTagNameNS( $NS, 'condition' ) ) {
+    foreach my $el ( $condata->getElementsByTagNameNS( $NS, 'condition' ) ) {
         my %con;
         my $c = $el->getFirstChild();
 
@@ -130,11 +131,7 @@ sub parse {
             $c = $c->getNextSibling();
         }
         push @conditions, \%con;
-        $mes->add_to_extra_info({from=>'no',type=>'text',message => $con{msg}, %con});
     }
-    # $oname is undef in case of $otype='session', so set it to $otype then
-    # to avoid warnings
-    $oname = $otype unless ($oname);
 
     # Extension results can be returned in all 3 object types
     $rinfo->{$otype}->{$oname}->{conditions} = \@conditions;
