@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Switch .CH/.LI EPP extensions
 ##
-## Copyright (c) 2008-2010,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
+## Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -11,17 +11,21 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::SWITCH;
 
 use strict;
-use warnings;
 
 use base qw/Net::DRI::Protocol::EPP/;
 
 use Net::DRI::Data::Contact::SWITCH;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -51,7 +55,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2010,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
+Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -65,16 +69,24 @@ See the LICENSE file that comes with this distribution for more details.
 
 ####################################################################################################
 
-sub setup
+sub new
 {
- my ($self,$rp)=@_;
- $self->capabilities('domain_update','status',undef);
- $self->capabilities('contact_update','status',undef);
- $self->factories('contact',sub { return Net::DRI::Data::Contact::SWITCH->new(); });
- return;
-}
+ my $c=shift;
+ my ($drd,$version,$extrah)=@_;
+ my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
 
-sub default_extensions { return qw/SecDNS GracePeriod/; }
+ my $self=$c->SUPER::new($drd,$version,[keys(%e)]); ## we are now officially a Net::DRI::Protocol::EPP object
+
+ my $rcapa=$self->capabilities();
+ delete($rcapa->{domain_update}->{status});
+ delete($rcapa->{contact_update}->{status}); 
+
+ my $rfact=$self->factories();
+ $rfact->{contact}=sub { return Net::DRI::Data::Contact::SWITCH->new(); };
+
+ bless($self,$c); ## rebless
+ return $self;
+}
 
 ####################################################################################################
 1;
