@@ -1,6 +1,6 @@
 ## Domain Registry Interface, OVH Web Services Account commands
 ##
-## Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,15 +10,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 #########################################################################################
 
 package Net::DRI::Protocol::OVH::WS::Account;
 
 use strict;
-use warnings;
 
 use Net::DRI::Exception;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -47,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -76,21 +80,19 @@ sub list_domains
  my ($po)=@_;
  my $msg=$po->message();
  $msg->method('domainList');
- return;
 }
 
 sub list_domains_parse
 {
- my ($po,$otype,$oaction,$oname,$rinfo)=@_;
+  my ($po,$otype,$oaction,$oname,$rinfo)=@_;
  my $mes=$po->message();
  return unless $mes->is_success();
 
  my $r=$mes->result();
- Net::DRI::Exception->die(1,'protocol/ovh/ws',1,'Unexpected reply for domainList: '.$r) unless (ref($r) eq 'MyArrayOfStringType');
+ Net::DRI::Exception->die(1,'protocol/ovh/ws',1,'Unexpected reply for domainList: '.$r) unless (ref($r) eq 'ArrayOfString');
  my @r=@$r;
  $rinfo->{account}->{domains}->{action}='list';
  $rinfo->{account}->{domains}->{list}=\@r;
- return;
 }
 
 ####################################################################################################
