@@ -1,6 +1,6 @@
 ## Domain Registry Interface, OVH Web Services Domain commands
 ##
-## Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,15 +10,25 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::OVH::WS::Domain;
 
 use strict;
-use warnings;
+
+use DateTime::Format::ISO8601;
 
 use Net::DRI::Exception;
 use Net::DRI::Util;
+use Net::DRI::Data::ContactSet;
+use Net::DRI::Data::Contact;
+use Net::DRI::Data::Hosts;
+use Net::DRI::Data::StatusList;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -48,7 +58,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -66,8 +76,7 @@ sub register_commands
 {
  my ($class,$version)=@_;
  my %tmp=(
-		info  => [\&info, \&info_parse ],
-		check => [\&check, \&check_parse ],
+		info => [\&info, \&info_parse ],
 	  );
 
  return { 'domain' => \%tmp };
@@ -75,9 +84,9 @@ sub register_commands
 
 sub parse_ArrayOfNsStruct
 {
- my ($po,$r)=@_;
- Net::DRI::Exception->die(1,'protocol/ovh/ws',1,'Unexpected content for dns: '.$r) unless (ref($r) eq 'MyArrayOfNsStructType');
- my $h=$po->create_local_object('hosts');
+ my ($r)=@_;
+ Net::DRI::Exception->die(1,'protocol/ovh/ws',1,'Unexpected content for dns: '.$r) unless (ref($r) eq 'ArrayOfNsStruct');
+ my $h=Net::DRI::Data::Hosts->new();
  foreach my $ns (@$r)
  {
   Net::DRI::Exception->die(1,'protocol/ovh/ws',1,'Unexpected content for ArrayOfNsStruct member: '.$ns) unless (ref($ns) eq 'nsStruct');
@@ -95,7 +104,6 @@ sub build_msg
  Net::DRI::Exception->die(1,'protocol/ovh/ws',10,'Invalid domain name') unless Net::DRI::Util::is_hostname($domain);
 
  $msg->method($command) if defined($command);
- return;
 }
 
 sub info
@@ -103,8 +111,7 @@ sub info
  my ($po,$domain)=@_;
  my $msg=$po->message();
  build_msg($msg,'domainInfo',$domain);
- $msg->params([$domain]);
- return;
+ $msg->params({ domain => $domain });
 }
 
 sub info_parse
@@ -114,24 +121,25 @@ sub info_parse
  return unless $mes->is_success();
 
  my $r=$mes->result();
- Net::DRI::Exception->die(1,'protocol/ovh/ws',1,'Unexpected reply for domain_info: '.$r) unless (ref($r) eq 'domainInfoReturn');
+ Net::DRI::Exception->die(1,'protocol/ovh/ws',1,'Unexpected reply for domainInfo: '.$r) unless (ref($r) eq 'domainInfoReturn');
 
  my %r=%$r;
  $oname=lc($r->{domain});
  $rinfo->{domain}->{$oname}->{action}='info';
  $rinfo->{domain}->{$oname}->{exist}=1;
+ my $pd=DateTime::Format::ISO8601->new();
  my %d=(creation => 'crDate', modification => 'upDate', expiration => 'exDate');
  while (my ($k,$v)=each(%d))
  {
   next unless exists($r{$k});
-  $rinfo->{domain}->{$oname}->{$v}=$po->parse_iso8601($r{$k});
+  $rinfo->{domain}->{$oname}->{$v}=$pd->parse_datetime($r{$k});
  }
  my %c=(nicowner => 'registrant', nicadmin => 'admin', nictech => 'tech', nicbilling => 'billing');
- my $cs=$po->create_local_object('contactset');
- while (my ($k,$v)=each(%c))
+ my $cs=Net::DRI::Data::ContactSet->new();
+ while (my ($k,$v)=each(%d))
  {
   next unless exists($r{$k});
-  my $c=$po->create_local_object('contact')->srid($r{$k});
+  my $c=Net::DRI::Data::Contact->new()->srid($r{$k});
   $cs->add($c,$v);
  }
  $rinfo->{domain}->{$oname}->{contact}=$cs;
@@ -140,38 +148,12 @@ sub info_parse
  if (exists($r{authinfo}))
  {
   $rinfo->{domain}->{$oname}->{auth}={pw => $r{authinfo}};
-  $rinfo->{domain}->{$oname}->{status}=$po->create_local_object('status')->add('ok');
+  $rinfo->{domain}->{$oname}->{status}=Net::DRI::Data::StatusList->new()->add('ok');
  } else
  {
-  $rinfo->{domain}->{$oname}->{status}=$po->create_local_object('status')->add('clientLock'); ## ? ##
+  $rinfo->{domain}->{$oname}->{status}=Net::DRI::Data::StatusList->new()->add('clientLock'); ## ? ##
  }
- $rinfo->{domain}->{$oname}->{ns}=parse_ArrayOfNsStruct($po,$r{dns}) if exists($r{dns});
- return;
-}
-
-sub check
-{
- my ($po,$domain)=@_;
- my $msg=$po->message();
- build_msg($msg,'domainCheck',$domain);
- $msg->params([$domain]);
- return;
-}
-
-sub check_parse
-{
- my ($po,$otype,$oaction,$oname,$rinfo)=@_;
- my $mes=$po->message();
- return unless $mes->is_success();
-
- my $r=$mes->result();
- Net::DRI::Exception->die(1,'protocol/ovh/ws',1,'Unexpected reply for domain_check: '.$r) unless (ref($r) eq 'MyArrayOfDomainCheckStructType');
-
- my @r=grep { exists $_->{predicate} && $_->{predicate} eq 'is_available' } @$r; ## also: is_transferable, is_renewable
- $rinfo->{domain}->{$oname}->{action}='check';
- $rinfo->{domain}->{$oname}->{exist}=(@r==1 && $r[0]->{value}==1)? 0 : 1;
- $rinfo->{domain}->{$oname}->{exist_reason}=$r[0]->{reason} if @r==1;
- return;
+ $rinfo->{domain}->{$oname}->{ns}=parse_ArrayOfNsStruct($r{dns}) if exists($r{dns});
 }
 
 ####################################################################################################
