@@ -1,6 +1,6 @@
 ## Domain Registry Interface, RRI Connection handling
 ##
-## Copyright (c) 2007-2009,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
+## Copyright (c) 2007 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,17 +10,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-####################################################################################################
+#
+# 
+#
+#########################################################################################
 
 package Net::DRI::Protocol::RRI::Connection;
 
 use strict;
-use warnings;
-
-use Net::DRI::Util;
 use Net::DRI::Data::Raw;
 use Net::DRI::Protocol::ResultStatus;
 
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -49,7 +51,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2009,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
+Copyright (c) 2007 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -65,7 +67,8 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub login
 {
- my ($class, $cm, $id, $pass, $cltrid, $dr, $newpass, $pdata) = @_;
+ shift if ($_[0] eq __PACKAGE__);
+ my ($cm, $id, $pass, $cltrid, $dr, $newpass, $pdata) = @_;
 
  my $mes=$cm->();
  $mes->command(['login']);
@@ -73,67 +76,61 @@ sub login
  push @d,['user',$id];
  push @d,['password',$pass];
  $mes->command_body(\@d);
- return $mes;
+ return $mes->as_string('tcp');
 }
 
 sub logout
 {
- my ($class,$cm,$cltrid)=@_;
+ shift if ($_[0] eq __PACKAGE__);
+ my ($cm,$cltrid)=@_;
  my $mes=$cm->();
  $mes->command(['logout']);
  $mes->cltrid($cltrid) if $cltrid;
- return $mes;
+ return $mes->as_string('tcp');
 }
 
 sub keepalive
 {
- my ($class,$cm,$cltrid)=@_;
+ shift if ($_[0] eq __PACKAGE__);
+ my ($cm,$cltrid)=@_;
  my $mes=$cm->();
  $mes->command(['hello']);
- return $mes;
+ return $mes->as_string('tcp');
 }
 
 ####################################################################################################
 
-sub read_data
+sub get_data
 {
- my ($class,$to,$sock)=@_;
+ shift if ($_[0] eq __PACKAGE__);
+ my ($to,$sock)=@_;
 
  my $version = $to->{transport}->{protocol_version};
- my $m='';
+ my $m;
  my $c;
- my $rl=$sock->sysread($c, 4); ## first 4 bytes are the packed length
- die(Net::DRI::Protocol::ResultStatus->new_error('COMMAND_FAILED_CLOSING',
-	'Unable to read RRI 4 bytes length (connection closed by registry ?): '.$!,
-	'en')) unless (defined $rl && $rl==4);
+ $sock->read($c, 4); ## first 4 bytes are the packed length
+ die(Net::DRI::Protocol::ResultStatus->new_error('COMMAND_SYNTAX_ERROR',
+	'Unable to read RRI 4 bytes length (connection closed by registry ?)',
+	'en')) unless $c;
  my $length = unpack('N', $c);
  while ($length > 0)
  {
   my $new;
-  $length-=$sock->sysread($new,$length);
+  $length-=$sock->read($new,$length);
   $m.=$new;
  }
 
- $m=Net::DRI::Util::decode_utf8($m);
  die(Net::DRI::Protocol::ResultStatus->new_error('COMMAND_SYNTAX_ERROR',
 	$m ? $m : '<empty message from server>', 'en'))
 	unless ($m =~ m!</registry-response>$!);
 
- return Net::DRI::Data::Raw->new_from_xmlstring($m);
-}
-
-sub write_message
-{
- my ($self,$to,$msg)=@_;
-
- my $m=Net::DRI::Util::encode_utf8($msg->as_string());
- my $l = pack('N', length($m)); ## DENIC-11
- return $l.$m;
+ return Net::DRI::Data::Raw->new_from_string($m);
 }
 
 sub parse_login
 {
- my ($class,$dc)=@_;
+ shift if ($_[0] eq __PACKAGE__);
+ my $dc=shift;
  my ($result,$code,$msg)=find_result($dc);
  unless (defined($result) && ($result eq 'success'))
  {
@@ -148,7 +145,8 @@ sub parse_login
 
 sub parse_logout
 {
- my ($class,$dc)=@_;
+ shift if ($_[0] eq __PACKAGE__);
+ my $dc=shift;
  my ($result,$code,$msg)=find_result($dc);
  unless (defined($result) && ($result eq 'success'))
  {
@@ -174,11 +172,5 @@ sub find_result
  return ($result, $code, $msg);
 }
 
-sub transport_default
-{
- my ($self,$tname)=@_;
- return ();
-}
-
 ####################################################################################################
 1;
