@@ -1,7 +1,6 @@
 ## Domain Registry Interface, RRI Message
 ##
-## Copyright (c) 2007-2009,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
-##           (c) 2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007,2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,14 +10,17 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::RRI::Message;
 
 use strict;
-use warnings;
 
 use XML::LibXML ();
+use Encode ();
 
 use Net::DRI::Protocol::ResultStatus;
 use Net::DRI::Exception;
@@ -28,6 +30,8 @@ use base qw(Class::Accessor::Chained::Fast Net::DRI::Protocol::Message);
 __PACKAGE__->mk_accessors(qw(version command command_body cltrid svtrid result
 	errcode errmsg node_resdata result_extra_info));
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -56,7 +60,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2009,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
+Copyright (c) 2007,2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -96,7 +100,7 @@ sub ns
   return $what;
  }
  return unless exists($self->{ns}->{$what});
- return $self->{ns}->{$what};
+ return $self->{ns}->{$what}->[0];
 }
 
 sub is_success { return (shift->result() =~ m/^success/)? 1 : 0; }
@@ -114,9 +118,10 @@ sub result_status
 
 sub as_string
 {
- my ($self)=@_;
+ my ($self,$to)=@_;
  my $rns=$self->ns();
- my $ens=sprintf('xmlns="%s"', $rns->{rri});
+ my $topns=$rns->{_main};
+ my $ens=sprintf('xmlns="%s"', $topns->[0]);
  my $cmdi = $self->command();
  my @d;
  push @d,'<?xml version="1.0" encoding="UTF-8" standalone="yes"?>';
@@ -125,14 +130,14 @@ sub as_string
 
  $attr = '' unless (defined($attr));
  $attr = ' ' . join(' ', map { $_ . '="' . $attr->{$_} . '"' }
-	sort { $a cmp $b } keys (%{$attr})) if (ref($attr) eq 'HASH');
+	keys (%{$attr})) if (ref($attr) eq 'HASH');
 
  if (defined($ns))
  {
   if (ref($ns) eq 'HASH')
   {
    $ens .= ' ' . join(' ', map { 'xmlns:' . $_ . '="' . $ns->{$_} . '"' }
-	sort { $a cmp $b } keys(%{$ns}));
+	keys(%{$ns}));
    $cmd = $type . ':' . $cmd;
   }
   else
@@ -153,7 +158,7 @@ sub as_string
  if (defined($body) && $body)
  {
   push @d,'<'.$cmd.$attr.'>';
-  push @d,Net::DRI::Util::xml_write($body);
+  push @d,_toxml($body);
   push @d,'</'.$cmd.'>';
  } else
  {
@@ -167,10 +172,54 @@ sub as_string
 		Net::DRI::Util::xml_is_token($cltrid,3,64));
  push @d,'</registry-request>';
 
- return join('',@d);
+ my $m=Encode::encode('utf8',join('',@d));
+ my $l = pack('N', length($m)); ## DENIC-11
+ return (defined($to) && ($to eq 'tcp') ? $l . $m : $m);
 }
 
-sub topns { return shift->ns->{rri}; }
+sub _toxml
+{
+ my $rd=shift;
+ my @t;
+ foreach my $d ((ref($rd->[0]))? @$rd : ($rd)) ## $d is a node=ref array
+ {
+  my @c; ## list of children nodes
+  my %attr;
+  foreach my $e (grep { defined } @$d)
+  {
+   if (ref($e) eq 'HASH')
+   {
+    while(my ($k,$v)=each(%$e)) { $attr{$k}=$v; }
+   } else
+   {
+    push @c,$e;
+   }
+  }
+  my $tag=shift(@c);
+  my $attr=keys(%attr)? ' '.join(' ',map { $_.'="'.$attr{$_}.'"' } sort(keys(%attr))) : '';
+  if (!@c || (@c==1 && !ref($c[0]) && ($c[0] eq '')))
+  {
+   push @t,'<'.$tag.$attr.'/>';
+  } else
+  {
+   push @t,'<'.$tag.$attr.'>';
+   push @t,(@c==1 && !ref($c[0]))? xml_escape($c[0]) : _toxml(\@c);
+   push @t,'</'.$tag.'>';
+  }
+ }
+ return @t;
+}
+
+sub xml_escape
+{
+ my $in=shift;
+ $in=~s/&/&amp;/g;
+ $in=~s/</&lt;/g;
+ $in=~s/>/&gt;/g;
+ return $in;
+}
+
+sub topns { return shift->ns->{_main}->[0]; }
 
 sub get_content
 {
@@ -180,7 +229,9 @@ sub get_content
  my @tmp;
  my $n1=$self->node_resdata();
 
- @tmp=$n1->getElementsByTagNameNS($ns // $self->topns(),$nodename) if (defined($n1));
+ $ns||=$self->topns();
+
+ @tmp=$n1->getElementsByTagNameNS($ns,$nodename) if (defined($n1));
 
  return unless @tmp;
  return wantarray()? @tmp : $tmp[0];
@@ -189,6 +240,7 @@ sub get_content
 sub parse
 {
  my ($self,$dc,$rinfo)=@_;
+ my $NS=$self->topns();
  my $trNS = $self->ns('tr');
  my $parser=XML::LibXML->new();
  my $xstr = $dc->as_string();
@@ -230,7 +282,8 @@ sub parse
    }
    else
    {
-    push @extra, { from => 'rri', type => 'text', code => $msg->getAttribute('code'), message => (defined $text ? $text->textContent() : '') };
+    push @extra, $msg->getAttribute('code') . (defined($text) ? ': ' .
+    $text->getFirstChild()->getData() : '');
    }
   }
   $self->result_extra_info(\@extra);
@@ -252,8 +305,6 @@ sub parse
   my @cltrid = $res->getElementsByTagNameNS($trNS, 'ctid');
   $self->cltrid($cltrid[0]->firstChild()->getData());
  }
-
- return;
 }
 
 ####################################################################################################
