@@ -1,6 +1,6 @@
 ## Domain Registry Interface, RRP Message
 ##
-## Copyright (c) 2005,2006,2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2006,2007,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -27,7 +27,7 @@ use Net::DRI::Protocol::ResultStatus;
 use base qw(Class::Accessor::Chained::Fast Net::DRI::Protocol::Message);
 __PACKAGE__->mk_accessors(qw(version errcode errmsg command));
 
-our $VERSION=do { my @r=(q$Revision: 1.14 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.15 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -57,7 +57,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2006,2007 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2006,2007,2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -69,6 +69,7 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
+####################################################################################################
 
 our $EOL="\r\n"; ## as mandated by RFC 2832
 
@@ -222,19 +223,7 @@ sub options
  return exists($self->{options})? $self->{options} : {};
 }
 
-########################################################################
-
-sub get_name_from_message
-{
- my ($self)=@_;
- my $ename=$self->entities('EntityName');
-
- return uc($self->entities('DomainName')) if ($ename eq 'Domain');
- return uc($self->entities('NameServer')) if ($ename eq 'NameServer');
-}
-
-#############################################################################################
-
+####################################################################################################
 
 %CODES=(
         200 => 1000, # Command completed successfully
